import 'package:clx_flutter_net/clx_flutter_net.dart';
import 'package:clx_flutter_util/clx_flutter_util.dart';
import 'dio_utils.dart';
import 'service_api.dart';

class NetUtil {
  static Future<void> get(
    url, {
    required queryParameters,
    NetSuccessCallback? successCallback,
    NetSuccessListCallback? successListCallback,
    NetErrorCallback? errorCallback,
    Options? options,
  }) async {
    DioUtils.instance.request(
        requestUrl: url,
        queryParameters: queryParameters,
        method: Method.get,
        successCallback: (data) {
          successListCallback?.call(data) ?? successCallback?.call(data);
        },
        errorCallback: (code, msg) {
          errorCallback != null
              ? errorCallback.call(code, msg)
              : ToastUtil.showToast(msg);
        },
        options: options);
  }

  static Future<void> post(
    url, {
    required data,
    dynamic queryParameters,
    NetSuccessCallback? successCallback,
    NetSuccessListCallback? successListCallback,
    NetErrorCallback? errorCallback,
    Options? options,
  }) async {
    DioUtils.instance.request(
        requestUrl: url,
        method: Method.post,
        data: data,
        queryParameters: queryParameters,
        successCallback: (data) {
          successListCallback?.call(data) ?? successCallback?.call(data);
        },
        errorCallback: (code, msg) {
          errorCallback != null
              ? errorCallback.call(code, msg)
              : ToastUtil.showToast(msg);
        },
        options: options);
  }

  static Future<void> put(
    url, {
    Map<String, dynamic>? queryParameters,
    Map<String, dynamic>? data,
    required NetSuccessCallback successCallback,
    NetErrorCallback? errorCallback,
    Options? options,
  }) async {
    DioUtils.instance.request(
        requestUrl: url,
        method: Method.put,
        queryParameters: queryParameters,
        data: data,
        successCallback: successCallback,
        errorCallback: (code, msg) {
          errorCallback != null
              ? errorCallback.call(code, msg)
              : ToastUtil.showToast(msg);
        },
        options: options);
  }

  static Future<void> delete(
    url, {
    Map<String, dynamic>? queryParameters,
    Map<String, dynamic>? data,
    required NetSuccessCallback successCallback,
    NetErrorCallback? errorCallback,
    Options? options,
  }) async {
    DioUtils.instance.request(
        requestUrl: url,
        method: Method.delete,
        queryParameters: queryParameters,
        data: data,
        successCallback: successCallback,
        errorCallback: (code, msg) {
          errorCallback != null
              ? errorCallback.call(code, msg)
              : ToastUtil.showToast(msg);
        },
        options: options);
  }

  // 上传图片到服务 表单上传
  static Future<String> uploadImage({
    required String path,
  }) async {
    String imageUrl = '';

    var formData = FormData.fromMap({
      'file': await MultipartFile.fromFile(path, filename: 'image.png'),
      'dir': 'carrier-driver',
    });

    var data = await DioUtils.instance.requestSync(
        requestUrl: ServiceApi.uploadImage,
        method: Method.post,
        data: formData);

    if (data != null) {
      String url = data['data'];
      imageUrl = url;
    } else {
      ToastUtil.showToast("图片上传失败，请联系公司管理员或客服");
    }

    return imageUrl;
  }

  //同步请求
  static Future getSync(String url) async {
    return DioUtils.instance
        .requestSync(requestUrl: url, method: Method.get);
  }
}
